Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1360)

Unified Diff: content/browser/frame_host/render_frame_host_manager.cc

Issue 2716583003: Rename Origin.unique() to opaque().
Patch Set: Update new uses post-rebase Created 3 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_manager.cc
diff --git a/content/browser/frame_host/render_frame_host_manager.cc b/content/browser/frame_host/render_frame_host_manager.cc
index af7ba906a7c3f8bf037204bf2b2fd1ef813b9836..a48fc813a5a24e4d33fc7a5cb8b0f9319234935c 100644
--- a/content/browser/frame_host/render_frame_host_manager.cc
+++ b/content/browser/frame_host/render_frame_host_manager.cc
@@ -1577,7 +1577,7 @@ bool RenderFrameHostManager::IsCurrentlySameSite(RenderFrameHostImpl* candidate,
// It is possible that last_successful_url() was a nonstandard scheme (for
// example, "about:blank"). If so, examine the replicated origin to determine
// the site.
- if (!candidate->GetLastCommittedOrigin().unique() &&
+ if (!candidate->GetLastCommittedOrigin().opaque() &&
SiteInstance::IsSameWebSite(
browser_context,
GURL(candidate->GetLastCommittedOrigin().Serialize()), dest_url)) {
@@ -2786,16 +2786,16 @@ bool RenderFrameHostManager::CanSubframeSwapProcess(
if (!SiteIsolationPolicy::AreCrossProcessFramesPossible())
return false;
// If dest_url is a unique origin like about:blank, then the need for a swap
// is determined by the source_instance or dest_instance.
GURL resolved_url = dest_url;
- if (url::Origin(resolved_url).unique()) {
+ if (url::Origin(resolved_url).opaque()) {
if (source_instance) {
resolved_url = source_instance->GetSiteURL();
} else if (dest_instance) {
resolved_url = dest_instance->GetSiteURL();
} else {
// If there is no SiteInstance this unique origin can be associated with,
// there are two cases:
// (1) If there was a server redirect, allow a process swap. Normally,
// redirects to data: or about: URLs are disallowed as
@@ -2786,16 +2786,16 @@ bool RenderFrameHostManager::CanSubframeSwapProcess(
if (!SiteIsolationPolicy::AreCrossProcessFramesPossible())
return false;
- // If dest_url is a unique origin like about:blank, then the need for a swap
+ // If dest_url is an opaque origin like about:blank, then the need for a swap
// is determined by the source_instance or dest_instance.
GURL resolved_url = dest_url;
@@ -2786,16 +2786,16 @@ bool RenderFrameHostManager::CanSubframeSwapProcess(
resolved_url = dest_instance->GetSiteURL();
} else {
- // If there is no SiteInstance this unique origin can be associated with,
+ // If there is no SiteInstance this opaque origin can be associated with,
// there are two cases:
// (1) If there was a server redirect, allow a process swap. Normally,
« no previous file with comments | « content/browser/frame_host/render_frame_host_impl.cc ('k') | content/browser/indexed_db/indexed_db_dispatcher_host.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698